@@ -20,13 +20,17 @@ CONFIG_FILE_BACKUP = os.path.join(BIBLEMATEGUI_USER_DIR, "biblemategui.config")
 
 def write_user_config():
     """Writes the current configuration to the user's config file."""
-    configurations = f"""config.avatar="{config.avatar}"
+    configurations = f"""config.hot_reload="{config.hot_reload}
+config.avatar="{config.avatar}"
+config.custom_token="{config.custom_token}"
 config.storage_secret="{config.storage_secret}"
 config.port={config.port}"""
     writeTextFile(CONFIG_FILE_BACKUP, configurations)
 
 # restore config backup after upgrade
-default_config = '''config.avatar=""
+default_config = '''config.hot_reload=False
+config.avatar=""
+config.custom_token=""
 config.storage_secret="REPLACE_ME_WITH_A_REAL_SECRET"
 config.port=33355'''
 
@@ -65,5 +69,6 @@ config.original_linguistic = original_linguistic
 config.bible_translation = bible_translation
 
 # general settings; stored on sever side
-config.bibles = {os.path.basename(i)[:-6]: i for i in glob.glob(os.path.join(BIBLEMATEGUI_DATA, "bibles", "*.bible"))}
-config.bibles_custom = {os.path.basename(i)[:-6]: i for i in glob.glob(os.path.join(BIBLEMATEGUI_DATA_CUSTOM, "bibles", "*.bible"))}
\ No newline at end of file
+config.bibles = dict(sorted({os.path.basename(i)[:-6]: i for i in glob.glob(os.path.join(BIBLEMATEGUI_DATA, "bibles", "*.bible"))}.items()))
+config.bibles_custom = dict(sorted({os.path.basename(i)[:-6]: i for i in glob.glob(os.path.join(BIBLEMATEGUI_DATA_CUSTOM, "bibles", "*.bible"))}.items()))
+config.available_tools = ["audio", "chronology"]
\ No newline at end of file
